========================
Team and repository tags
========================

.. image:: https://governance.openstack.org/tc/badges/mistral.svg
    :target: https://governance.openstack.org/tc/reference/tags/index.html

Mistral
=======

Workflow Service integrated with OpenStack. This project aims to provide a
mechanism to define tasks and workflows in a simple YAML-based language, manage
and execute them in a distributed environment.

Project Resources
-----------------

* `Mistral Official Documentation <https://docs.openstack.org/mistral/latest/>`_

    * `User Documentation <https://docs.openstack.org/mistral/latest/user/index.html>`_

    * `Administrator Documentation <https://docs.openstack.org/mistral/latest/admin/index.html>`_

    * `Developer Documentation <https://docs.openstack.org/mistral/latest/developer/index.html>`_

* Project status, bugs, and blueprints are tracked on
  `Launchpad <https://launchpad.net/mistral/>`_

* CloudFlow: visualization tool for workflow executions on https://github.com/nokia/CloudFlow

* Apache License Version 2.0 http://www.apache.org/licenses/LICENSE-2.0

* Release notes for the project can be found at:
  https://docs.openstack.org/releasenotes/mistral/

* Source for the project can be found at:
  https://opendev.org/openstack/mistral

* WSGI app is located in `mistral/api/wsgi.py`
